<?php

use Illuminate\Support\Facades\Route;

use Koneko\VuexyWarehouse\Http\Controllers\ProductCategorieController;
use Koneko\VuexyWarehouse\Http\Controllers\ProductCatalogController;
use Koneko\VuexyWarehouse\Http\Controllers\ProductController;
use Koneko\VuexyWarehouse\Http\Controllers\PurchaseOrderController;
use Koneko\VuexyWarehouse\Http\Controllers\ProductReceiptController;
use Koneko\VuexyWarehouse\Http\Controllers\MaterialController;
use Koneko\VuexyWarehouse\Http\Controllers\WarehouseController;
use Koneko\VuexyWarehouse\Http\Controllers\InventoryStockController;
use Koneko\VuexyWarehouse\Http\Controllers\InventoryMovementController;
use Koneko\VuexyWarehouse\Http\Controllers\WarehouseTransfersController;
use Koneko\VuexyWarehouse\Http\Controllers\ShippingOrderController;
use Koneko\VuexyWarehouse\Http\Controllers\ShipmentTrackingController;
use Koneko\VuexyWarehouse\Http\Controllers\ShippingCarrierController;
use Koneko\VuexyWarehouse\Http\Controllers\ShippingRateController;
use Koneko\VuexyWarehouse\Http\Controllers\AssetController;
use Koneko\VuexyWarehouse\Http\Controllers\AssetMaintenanceController;
use Koneko\VuexyWarehouse\Http\Controllers\AssetLifecycleController;
use Koneko\VuexyWarehouse\Http\Controllers\AssetAassignmentController;

// Grupo raíz para admin con middleware y prefijos comunes
Route::prefix('admin/productos-y-servicios')->name('admin.inventory.')->middleware(['web', 'auth', 'admin'])->group(function () {
    Route::controller(ProductCategorieController::class)->prefix('categorias')->name('product-categories.')->group(function () {
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'categorie')->name('store');  // Guardar
        Route::get('{categorie}', 'show')->name('show');  // Ver
        Route::get('{categorie}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{categorie}', 'update')->name('update');  // Actualizar
        Route::delete('{categorie}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ProductCatalogController::class)->prefix('catalogos')->name('product-catalogs.')->group(function () {
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'catalog')->name('store');  // Guardar
        Route::get('{catalog}', 'show')->name('show');  // Ver
        Route::get('{catalog}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{catalog}', 'update')->name('update');  // Actualizar
        Route::delete('{catalog}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ProductController::class)->prefix('productos')->name('products.')->group(function () {
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'product')->name('store');  // Guardar
        Route::get('{product}', 'show')->name('show');  // Ver
        Route::get('{product}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{product}', 'update')->name('update');  // Actualizar
        Route::delete('{product}', 'destroy')->name('destroy');  // Eliminar
    });
});

Route::prefix('admin/inventario-y-logistica')->name('admin.inventory.')->middleware(['web', 'auth', 'admin'])->group(function () {
    Route::controller(PurchaseOrderController::class)->prefix('ordenes-de-compra')->name('orders.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'orders')->name('store');  // Guardar
        Route::get('{orders}', 'show')->name('show');  // Ver
        Route::get('{orders}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{orders}', 'update')->name('update');  // Actualizar
        Route::delete('{orders}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ProductReceiptController::class)->prefix('recepcion-de-productos')->name('reception.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'reception')->name('store');  // Guardar
        Route::get('{reception}', 'show')->name('show');  // Ver
        Route::get('{reception}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{reception}', 'update')->name('update');  // Actualizar
        Route::delete('{reception}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(MaterialController::class)->prefix('gestion-de-insumos')->name('materials.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'materials')->name('store');  // Guardar
        Route::get('{materials}', 'show')->name('show');  // Ver
        Route::get('{materials}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{materials}', 'update')->name('update');  // Actualizar
        Route::delete('{materials}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(WarehouseController::class)->prefix('almacenes')->name('warehouse.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'warehouse')->name('store');  // Guardar
        Route::get('{warehouse}', 'show')->name('show');  // Ver
        Route::get('{warehouse}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{warehouse}', 'update')->name('update');  // Actualizar
        Route::delete('{warehouse}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(InventoryStockController::class)->prefix('stock-de-inventario')->name('stock.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'stock')->name('store');  // Guardar
        Route::get('{stock}', 'show')->name('show');  // Ver
        Route::get('{stock}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{stock}', 'update')->name('update');  // Actualizar
        Route::delete('{stock}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(InventoryMovementController::class)->prefix('movimientos-de-inventario')->name('movements.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'movements')->name('store');  // Guardar
        Route::get('{movements}', 'show')->name('show');  // Ver
        Route::get('{movements}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{movements}', 'update')->name('update');  // Actualizar
        Route::delete('{movements}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(WarehouseTransfersController::class)->prefix('transferencias-entre-almacenes')->name('transfers.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'transfers')->name('store');  // Guardar
        Route::get('{transfers}', 'show')->name('show');  // Ver
        Route::get('{transfers}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{transfers}', 'update')->name('update');  // Actualizar
        Route::delete('{transfers}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ShippingOrderController::class)->prefix('ordenes-de-envio')->name('shipping-orders.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'shipping-order')->name('store');  // Guardar
        Route::get('{shipping-order}', 'show')->name('show');  // Ver
        Route::get('{shipping-order}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{shipping-order}', 'update')->name('update');  // Actualizar
        Route::delete('{shipping-order}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ShipmentTrackingController::class)->prefix('seguimiento-de-envios')->name('shipping-tracking.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'shippingTracking')->name('store');  // Guardar
        Route::get('{shippingTracking}', 'show')->name('show');  // Ver
        Route::get('{shippingTracking}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{shippingTracking}', 'update')->name('update');  // Actualizar
        Route::delete('{shippingTracking}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ShippingCarrierController::class)->prefix('transportistas')->name('shipping-carriers.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'shippingCarrier')->name('store');  // Guardar
        Route::get('{shippingCarrier}', 'show')->name('show');  // Ver
        Route::get('{shippingCarrier}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{shippingCarrier}', 'update')->name('update');  // Actualizar
        Route::delete('{shippingCarrier}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(ShippingRateController::class)->prefix('tarifas-y-metodos-de-envio')->name('shipping-rates.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'shippingRate')->name('store');  // Guardar
        Route::get('{shippingRate}', 'show')->name('show');  // Ver
        Route::get('{shippingRate}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{shippingRate}', 'update')->name('update');  // Actualizar
        Route::delete('{shippingRate}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(AssetController::class)->prefix('activos-registrados')->name('assets.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'asset')->name('store');  // Guardar
        Route::get('{asset}', 'show')->name('show');  // Ver
        Route::get('{asset}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{asset}', 'update')->name('update');  // Actualizar
        Route::delete('{asset}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(AssetMaintenanceController::class)->prefix('mantenimiento-preventivo')->name('asset-maintenance.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'assetMaintenance')->name('store');  // Guardar
        Route::get('{assetMaintenance}', 'show')->name('show');  // Ver
        Route::get('{assetMaintenance}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{assetMaintenance}', 'update')->name('update');  // Actualizar
        Route::delete('{assetMaintenance}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(AssetLifecycleController::class)->prefix('control-de-vida-util')->name('asset-lifecycle.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'assetLifecycle')->name('store');  // Guardar
        Route::get('{assetLifecycle}', 'show')->name('show');  // Ver
        Route::get('{assetLifecycle}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{assetLifecycle}', 'update')->name('update');  // Actualizar
        Route::delete('{assetLifecycle}', 'destroy')->name('destroy');  // Eliminar
    });

    Route::controller(AssetAassignmentController::class)->prefix('asignacion-de-activos')->name('asset-assignments.')->group(function () {;
        Route::get('/', 'index')->name('index');  // Listar
        Route::get('create', 'create')->name('create');  // Formulario de creación
        Route::post('/', 'assetAssignmen')->name('store');  // Guardar
        Route::get('{assetAssignmen}', 'show')->name('show');  // Ver
        Route::get('{assetAssignmen}/edit', 'edit')->name('edit');  // Formulario de edición
        Route::put('{assetAssignmen}', 'update')->name('update');  // Actualizar
        Route::delete('{assetAssignmen}', 'destroy')->name('destroy');  // Eliminar
    });

});
